@@ -96,7 +96,6 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_XINERAMA),
     MAKE_ENTRY(NV_CTRL_XINERAMA_STEREO),
     MAKE_ENTRY(NV_CTRL_BUS_RATE),
-    MAKE_ENTRY(NV_CTRL_SHOW_SLI_VISUAL_INDICATOR),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY),
     MAKE_ENTRY(NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID),
     MAKE_ENTRY(NV_CTRL_PROBE_DISPLAYS),
@@ -163,7 +162,6 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_READING),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_PROVIDER),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_TARGET),
-    MAKE_ENTRY(NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR),
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_MAX_LINK_SPEED),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_RESET_TRANSCEIVER_TO_FACTORY_SETTINGS),
@@ -198,7 +196,7 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT),
     MAKE_ENTRY(NV_CTRL_DPY_HDMI_3D),
     MAKE_ENTRY(NV_CTRL_BASE_MOSAIC),
-    MAKE_ENTRY(NV_CTRL_MULTIGPU_MASTER_POSSIBLE),
+    MAKE_ENTRY(NV_CTRL_MULTIGPU_PRIMARY_POSSIBLE),
     MAKE_ENTRY(NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY_ID),
     MAKE_ENTRY(NV_CTRL_BACKLIGHT_BRIGHTNESS),
@@ -427,7 +425,7 @@ int main(void)
             printf("Screen %d supports the NV-CONTROL X extension\n", i);
 
             ret = XNVCTRLQueryStringAttribute(dpy, i,
-                                              0, /* XXX not curently used */
+                                              0, /* XXX not currently used */
                                               NV_CTRL_STRING_PRODUCT_NAME,
                                               &str);
             if (ret) {
@@ -436,7 +434,7 @@ int main(void)
             }
             
             ret = XNVCTRLQueryStringAttribute(dpy, i,
-                                              0, /* XXX not curently used */
+                                              0, /* XXX not currently used */
                                               NV_CTRL_STRING_VBIOS_VERSION,
                                               &str);
             
@@ -446,7 +444,7 @@ int main(void)
             }
 
             ret = XNVCTRLQueryStringAttribute(dpy, i,
-                                              0, /* XXX not curently used */
+                                              0, /* XXX not currently used */
                                               NV_CTRL_STRING_NVIDIA_DRIVER_VERSION,
                                               &str);
 
