@@ -255,8 +255,6 @@ typedef struct nvDisplayRec {
     char               *targetIdName;   /* e.g. "DPY-3" */
     char               *randrName;      /* e.g. "VGA-1", "DVI-I-2" */
 
-    Bool                is_sdi;         /* Is an SDI display */
-
     nvModeLinePtr       modelines;      /* Modelines validated by X */
     int                 num_modelines;
 
@@ -365,7 +363,6 @@ typedef struct nvScreenRec {
     int x_offset;                     /* Offsets for relative positioning */
     int y_offset;
 
-    Bool sli;
     char *sli_mode;
     char *multigpu_mode;
     Bool no_scanout;        /* This screen has no display devices */
@@ -378,15 +375,6 @@ typedef struct nvScreenRec {
 
 
 
-/* GVO Mode information */
-typedef struct GvoModeDataRec {
-    unsigned int id; /* NV-CONTROL ID */
-    char *name;
-    unsigned int rate; /* Refresh rate */
-} GvoModeData;
-
-
-
 /* GPU (Device) */
 typedef struct nvGpuRec {
     struct nvGpuRec *next_in_layout; /* List of all GPUs */
@@ -410,10 +398,7 @@ typedef struct nvGpuRec {
 
     gchar *pci_bus_id;
 
-    GvoModeData *gvo_mode_data; /* Information about GVO modes available */
-    unsigned int num_gvo_modes;
-
-    unsigned int *flags_memory; /* Pointer to memory alloced for flags */
+    unsigned int *flags_memory; /* Pointer to memory allocated for flags */
     unsigned int *flags; /* Array of flags queried from the X server */
     int num_flags;
 
